@@ -13,7 +13,7 @@ use HTTP::Date;
 use HTTP::Status qw{ :constants };
 use Test::More 0.96;	# For subtest
 
-our $VERSION = '0.143_04';
+our $VERSION = '0.143_05';
 
 # Set the following to zero if Space Track (or any other SSL host)
 # starts using a certificate that can not be verified.
@@ -213,6 +213,10 @@ sub not_defined {
 	    }
 	);
 
+	%skip_site = (
+	    'spaceflight.nasa.gov'	=> 'Site retired',
+	);
+
 	if ( defined $ENV{ASTRO_SPACETRACK_SKIP_SITE} ) {
 	    foreach my $site ( split qr{ \s* , \s* }smx,
 		$ENV{ASTRO_SPACETRACK_SKIP_SITE} ) {
